#!/bin/bash


#  Slackbuild script for gwenview
# Author: Mark Tucker
# Created: Jul 31, 2004
# Changes:
#        Jul 31, 2004 - initial creation
#        Oct 8, 2004 - updated for 1.1.5
#        Apr 1, 2005 - updated for ver. 1.2.0pre4
#        Apr 3, 2005  - updated for ver. 1.2.0  RELEASE !!!
#        Jul 22, 2005 - Updated for ver. 1.2.91
#                       Enabled sbuild.functions for most operations 
#        12 Oct, 2006 - Updated for ver. 1.4.0
#
#----------------------------------------------------------------------

umask 0022

#----------------------------------------
# include the common functions
#----------------------------------------
if [ -r ./sbuild.functions ]; then
    . ./sbuild.functions
else
    echo Cannot read file `pwd`/sbuild.functions
    echo Exiting....
    echo
    exit
fi

#----------------------------------------
# Set locations for temp directories
#----------------------------------------
# location of source code archive
srcdir=`pwd`/SRC
workdir=`pwd`


#----------------------------------------
# Package variables
#----------------------------------------
source="gwenview-1.4.0.tar.bz2"
pkgname="gwenview"
pkgver="1.4.0"
release="1mht"
package="$pkgname-$pkgver-i486-$release.tgz"
realname="Mark Tucker"
echo Package: $package

#----------------------------------------
# setup path variables
#----------------------------------------
set_workdir

# unpack the source
echo Unpacking the source...
tar -xjf $srcdir/$source


cd $builddir

#----------------------------------------
# setup the build environment
#----------------------------------------
export CFLAGS="-O2 -march=i486 -mcpu=i686"
export CPPFLAGS="-O2 -march=i486 -mcpu=i686"
export CXXFLAGS=$CPPFLAGS


#----------------------------------------
# Build the package and install
#----------------------------------------
# configure 
conf_opts=" --enable-kipi --prefix=/opt/kde"
run_configure $conf_opts

# make
run_make

# Set target directory
set_target

# install
run_makeinstall


echo finishing install...


# create install dir
mkdir $target/install

#----------------------------------------
# create slack-desc file to install
#----------------------------------------
cat > $target/install/slack-desc << END
             |-----handy-ruler------------------------------------------------------|
$pkgname: $pkgname $pkgver (development version of Gwenview)
$pkgname:
$pkgname: Gwenview is a simple image viewer for KDE. It features a folder tree
$pkgname: window and a file list window to provide easy navigation in your file
$pkgname: hierarchy.  Image loading is done by Qt library, so it supports all
$pkgname: image formats your Qt installation supports.
$pkgname:
$pkgname:
$pkgname: http://gwenview.sourceforge.net
$pkgname:
$pkgname: Packaged by $realname for $slackver / KDE 3.5.4
END


# create documentation directory
create_docdir

# fix group on bin directories.
fix_bingrp

# strip  bin files
strip_bin

# strip lib files
strip_libs

# check for uncompressed man pages
compr_man

# makepkg
create_pkg

exit

